const express = require('express');
const multer = require('multer');
const path = require('path');
const router = express.Router();
const {nanoid} = require('nanoid');
const config = require('./config');

    const storage = multer.diskStorage({
        destination: (req, file, cb) => {
            cb(null, config.uploadPath);
        },
        filename: (req, file, cb) => {
            cb(null, nanoid() + path.extname(file.originalname))
        }
    });
    const upload = multer({storage});

const createRouter = (db) => {
    router.get('/', async (req, res) => {

        const products = await db.getItems('products');
        res.send(products);
    });

    router.get('/:id', async (req, res) => {
       const product = await db.getItem('products', req.params.id);
       res.send(product[0]);
    });

    router.post('/', upload.single('image'), async (req, res) => {
        const product = req.body;
        if(req.file) {
            product.image = req.file.filename;
        }
        const newProduct = await db.addItem('products', product);
        res.send(newProduct);
    });

    return router;
};


module.exports = createRouter;